#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 blaze-markup
version:              0.8.2.8
visibility:           public
id:                   blaze-markup-0.8.2.8-3vU6uXP6yL6HskSuj4A8TX
key:                  blaze-markup-0.8.2.8-3vU6uXP6yL6HskSuj4A8TX
license:              BSD-3-Clause
maintainer:           Jasper Van der Jeugt <m@jaspervdj.be>
author:               Jasper Van der Jeugt, Simon Meier, Deepak Jois
stability:            Experimental
homepage:             http://jaspervdj.be/blaze
synopsis:             A blazingly fast markup combinator library for Haskell
description:
    Core modules of a blazingly fast markup combinator library for the Haskell
    programming language. The Text.Blaze module is a good
    starting point, as well as this tutorial:
    <http://jaspervdj.be/blaze/tutorial.html>.

category:             Text
abi:                  a0eabadb6f50e9bab5ab8a59a3a9638b
exposed:              True
exposed-modules:
    Text.Blaze Text.Blaze.Internal Text.Blaze.Renderer.Pretty
    Text.Blaze.Renderer.String Text.Blaze.Renderer.Text
    Text.Blaze.Renderer.Utf8

import-dirs:          /usr/lib/ghc-8.10.5/site-local/blaze-markup-0.8.2.8
library-dirs:         /usr/lib/ghc-8.10.5/site-local/blaze-markup-0.8.2.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/blaze-markup-0.8.2.8
hs-libraries:         HSblaze-markup-0.8.2.8-3vU6uXP6yL6HskSuj4A8TX
depends:
    base-4.14.2.0 blaze-builder-0.4.2.1-CvyaA91rGJh3LGq34EOJVB
    bytestring-0.10.12.0 text-1.2.4.1

haddock-interfaces:
    /usr/share/doc/haskell-blaze-markup/html/blaze-markup.haddock

haddock-html:         /usr/share/doc/haskell-blaze-markup/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

